@@ -14,6 +14,7 @@ from ..models import (
     Options,
     Polygon,
     QuadkeyQuery,
+    SectorQuery,
     TileQuery,
 )
 from ..responses import (
@@ -49,6 +50,7 @@ class Within(Executable):
         TileQuery,
         ObjectQuery,
         GetQuery,
+        SectorQuery,
     ]
     _output: Optional[Output] = None
     _all: bool = False
@@ -119,6 +121,19 @@ class Within(Executable):
 
         return self
 
+    def buffer(self, value: int) -> Within:
+        """Apply a buffer around area formats to increase the search area by x meters.
+
+        Args:
+            value (int): buffer size in meters
+
+        Returns:
+            Within
+        """
+        self._options["buffer"] = value
+
+        return self
+
     def limit(self, value: int) -> Within:
         """Limit the number of returned objects in a search.
 
@@ -282,6 +297,27 @@ class Within(Executable):
 
         return self
 
+    def sector(
+        self, lat: float, lon: float, radius: float, bearing1: float, bearing2: float
+    ) -> Within:
+        """Define a sector as inbound area type for the within search
+
+        Args:
+            lat (float): latitude of sector center
+            lon (float): longitude of sector center
+            radius (float): radius of sector
+            bearing1 (float): start bearing
+            bearing2 (float): end bearing
+
+        Returns:
+            Within
+        """
+        self._query = SectorQuery(
+            lat=lat, lon=lon, radius=radius, bearing1=bearing1, bearing2=bearing2
+        )
+
+        return self
+
     def tile(self, x: int, y: int, z: int) -> Within:
         """Define a tile as input bounding area for the within search.
 
